"""
"""

def send_get(context):
    """
    """
    context.response = context.session.get(context.request_url)


def send_post(context):
    """
    """
    context.response = context.session.post(
        context.request_url,
        json=context.request_json_payload
    )


def send_put(context):
    """
    """
    context.response = context.session.put(
        context.request_url,
        json=context.request_json_payload
    )


def send_delete(context):
    """
    """
    context.response = context.session.delete(
        context.request_url
    )


"""
"""
import json

def set_url(context, url):
    """
    """
    resolved_url = context.vars.resolve(url)
    context.request_url = resolved_url


def set_json_payload(context, payload):
    """
    """
    resolved_payload = context.vars.resolve(payload)
    context.request_json_payload = json.loads(resolved_payload)
